@@ -8,12 +8,12 @@ use warnings;
 use bytes;
 
 
-use IO::Compress::RawDeflate 2.032 ;
+use IO::Compress::RawDeflate 2.034 ;
 
-use Compress::Raw::Zlib  2.032 ;
-use IO::Compress::Base::Common  2.032 qw(:Status :Parse createSelfTiedObject);
-use IO::Compress::Gzip::Constants 2.032 ;
-use IO::Compress::Zlib::Extra 2.032 ;
+use Compress::Raw::Zlib  2.034 ;
+use IO::Compress::Base::Common  2.034 qw(:Status :Parse createSelfTiedObject);
+use IO::Compress::Gzip::Constants 2.034 ;
+use IO::Compress::Zlib::Extra 2.034 ;
 
 BEGIN
 {
@@ -27,7 +27,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $GzipError);
 
-$VERSION = '2.032';
+$VERSION = '2.034';
 $GzipError = '' ;
 
 @ISA    = qw(Exporter IO::Compress::RawDeflate);
@@ -512,8 +512,8 @@ data to the output data stream.
 
 So when the output is a filehandle it will carry out a seek to the eof
 before writing any compressed data. If the output is a filename, it will be opened for
-appending. If the output is a buffer, all compressed data will be appened to
-the existing buffer.
+appending. If the output is a buffer, all compressed data will be
+appended to the existing buffer.
 
 Conversely when C<Append> is not specified, or it is present and is set to
 false, it will operate as follows.
@@ -1086,7 +1086,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
