@@ -6,22 +6,22 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.032 qw(createSelfTiedObject);
+use IO::Compress::Base::Common  2.034 qw(createSelfTiedObject);
 
-use IO::Uncompress::Adapter::Inflate  2.032 ();
+use IO::Uncompress::Adapter::Inflate  2.034 ();
 
 
-use IO::Uncompress::Base  2.032 ;
-use IO::Uncompress::Gunzip  2.032 ;
-use IO::Uncompress::Inflate  2.032 ;
-use IO::Uncompress::RawInflate  2.032 ;
-use IO::Uncompress::Unzip  2.032 ;
+use IO::Uncompress::Base  2.034 ;
+use IO::Uncompress::Gunzip  2.034 ;
+use IO::Uncompress::Inflate  2.034 ;
+use IO::Uncompress::RawInflate  2.034 ;
+use IO::Uncompress::Unzip  2.034 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.032';
+$VERSION = '2.034';
 $AnyInflateError = '';
 
 @ISA = qw( Exporter IO::Uncompress::Base );
@@ -48,7 +48,7 @@ sub anyinflate
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.032 qw(:Parse);
+    use IO::Compress::Base::Common  2.034 qw(:Parse);
     return ( 'RawInflate' => [1, 1, Parse_boolean,  0] ) ;
 }
 
@@ -371,8 +371,8 @@ data to the output data stream.
 
 So when the output is a filehandle it will carry out a seek to the eof
 before writing any uncompressed data. If the output is a filename, it will be opened for
-appending. If the output is a buffer, all uncompressed data will be appened to
-the existing buffer.
+appending. If the output is a buffer, all uncompressed data will be
+appended to the existing buffer.
 
 Conversely when C<Append> is not specified, or it is present and is set to
 false, it will operate as follows.
@@ -562,7 +562,7 @@ the module will allow reading of it anyway.
 
 In addition, if the input file/buffer does contain compressed data and
 there is non-compressed data immediately following it, setting this option
-will make this module treat the whole file/bufffer as a single data stream.
+will make this module treat the whole file/buffer as a single data stream.
 
 This option defaults to 1.
 
@@ -856,7 +856,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
