@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.032 qw(createSelfTiedObject);
+use IO::Compress::Base::Common 2.034 qw(createSelfTiedObject);
 
-use IO::Uncompress::Base 2.032 ;
+use IO::Uncompress::Base 2.034 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.032';
+$VERSION = '2.034';
 $AnyUncompressError = '';
 
 @ISA = qw( Exporter IO::Uncompress::Base );
@@ -27,22 +27,22 @@ Exporter::export_ok_tags('all');
 
 BEGIN
 {
-   eval ' use IO::Uncompress::Adapter::Inflate 2.032 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.032 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.032 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.032 ;';
+   eval ' use IO::Uncompress::Adapter::Inflate 2.034 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.034 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.034 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.034 ;';
    eval ' use IO::Uncompress::Adapter::UnLzma 2.020 ;';
    eval ' use IO::Uncompress::Adapter::UnXz 2.020 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.032 ;';
-   eval ' use IO::Uncompress::UnLzop 2.032 ;';
-   eval ' use IO::Uncompress::Gunzip 2.032 ;';
-   eval ' use IO::Uncompress::Inflate 2.032 ;';
-   eval ' use IO::Uncompress::RawInflate 2.032 ;';
-   eval ' use IO::Uncompress::Unzip 2.032 ;';
-   eval ' use IO::Uncompress::UnLzf 2.032 ;';
-   eval ' use IO::Uncompress::UnLzma 2.032 ;';
-   eval ' use IO::Uncompress::UnXz 2.032 ;';
+   eval ' use IO::Uncompress::Bunzip2 2.034 ;';
+   eval ' use IO::Uncompress::UnLzop 2.034 ;';
+   eval ' use IO::Uncompress::Gunzip 2.034 ;';
+   eval ' use IO::Uncompress::Inflate 2.034 ;';
+   eval ' use IO::Uncompress::RawInflate 2.034 ;';
+   eval ' use IO::Uncompress::Unzip 2.034 ;';
+   eval ' use IO::Uncompress::UnLzf 2.034 ;';
+   eval ' use IO::Uncompress::UnLzma 2.034 ;';
+   eval ' use IO::Uncompress::UnXz 2.034 ;';
 }
 
 sub new
@@ -60,7 +60,7 @@ sub anyuncompress
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common 2.032 qw(:Parse);
+    use IO::Compress::Base::Common 2.034 qw(:Parse);
     return ( 'RawInflate' => [1, 1, Parse_boolean,  0] ,
              'UnLzma'     => [1, 1, Parse_boolean,  0] ) ;
 }
@@ -480,8 +480,8 @@ data to the output data stream.
 
 So when the output is a filehandle it will carry out a seek to the eof
 before writing any uncompressed data. If the output is a filename, it will be opened for
-appending. If the output is a buffer, all uncompressed data will be appened to
-the existing buffer.
+appending. If the output is a buffer, all uncompressed data will be
+appended to the existing buffer.
 
 Conversely when C<Append> is not specified, or it is present and is set to
 false, it will operate as follows.
@@ -671,7 +671,7 @@ the module will allow reading of it anyway.
 
 In addition, if the input file/buffer does contain compressed data and
 there is non-compressed data immediately following it, setting this option
-will make this module treat the whole file/bufffer as a single data stream.
+will make this module treat the whole file/buffer as a single data stream.
 
 This option defaults to 1.
 
@@ -904,7 +904,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
