@@ -8,14 +8,14 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate  2.032 ;
-use IO::Compress::Base::Common  2.032 qw(:Status createSelfTiedObject);
-use IO::Uncompress::Adapter::Inflate  2.032 ;
-use IO::Uncompress::Adapter::Identity 2.032 ;
-use IO::Compress::Zlib::Extra 2.032 ;
-use IO::Compress::Zip::Constants 2.032 ;
+use IO::Uncompress::RawInflate  2.034 ;
+use IO::Compress::Base::Common  2.034 qw(:Status createSelfTiedObject);
+use IO::Uncompress::Adapter::Inflate  2.034 ;
+use IO::Uncompress::Adapter::Identity 2.034 ;
+use IO::Compress::Zlib::Extra 2.034 ;
+use IO::Compress::Zip::Constants 2.034 ;
 
-use Compress::Raw::Zlib  2.032 qw(crc32) ;
+use Compress::Raw::Zlib  2.034 qw(crc32) ;
 
 BEGIN
 {
@@ -30,7 +30,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.032';
+$VERSION = '2.034';
 $UnzipError = '';
 
 @ISA    = qw(Exporter IO::Uncompress::RawInflate);
@@ -63,7 +63,7 @@ sub unzip
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.032 qw(:Parse);
+    use IO::Compress::Base::Common  2.034 qw(:Parse);
 
     
     return (
@@ -1009,8 +1009,8 @@ data to the output data stream.
 
 So when the output is a filehandle it will carry out a seek to the eof
 before writing any uncompressed data. If the output is a filename, it will be opened for
-appending. If the output is a buffer, all uncompressed data will be appened to
-the existing buffer.
+appending. If the output is a buffer, all uncompressed data will be
+appended to the existing buffer.
 
 Conversely when C<Append> is not specified, or it is present and is set to
 false, it will operate as follows.
@@ -1206,7 +1206,7 @@ the module will allow reading of it anyway.
 
 In addition, if the input file/buffer does contain compressed data and
 there is non-compressed data immediately following it, setting this option
-will make this module treat the whole file/bufffer as a single data stream.
+will make this module treat the whole file/buffer as a single data stream.
 
 This option defaults to 1.
 
@@ -1425,7 +1425,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
